from collections import namedtuple

Split = namedtuple("Split", ["feature_index", "threshold", "categories", "is_continuous"])
splits_iris = [[Split(feature_index=0, threshold=4.85, categories=None, is_continuous=True),
                           Split(feature_index=0, threshold=5.05, categories=None, is_continuous=True),
                           Split(feature_index=0, threshold=5.15, categories=None, is_continuous=True),
                           Split(feature_index=0, threshold=5.45, categories=None, is_continuous=True),
                           Split(feature_index=0, threshold=5.65, categories=None, is_continuous=True),
                           Split(feature_index=0, threshold=5.95, categories=None, is_continuous=True),
                           Split(feature_index=0, threshold=6.15, categories=None, is_continuous=True),
                           Split(feature_index=0, threshold=6.35, categories=None, is_continuous=True),
                           Split(feature_index=0, threshold=6.65, categories=None, is_continuous=True),
                           Split(feature_index=0, threshold=6.95, categories=None, is_continuous=True)],
                          [Split(feature_index=1, threshold=2.45, categories=None, is_continuous=True),
                           Split(feature_index=1, threshold=2.6500000000000004, categories=None, is_continuous=True),
                           Split(feature_index=1, threshold=2.8499999999999996, categories=None, is_continuous=True),
                           Split(feature_index=1, threshold=2.95, categories=None, is_continuous=True),
                           Split(feature_index=1, threshold=3.05, categories=None, is_continuous=True),
                           Split(feature_index=1, threshold=3.1500000000000004, categories=None, is_continuous=True),
                           Split(feature_index=1, threshold=3.25, categories=None, is_continuous=True),
                           Split(feature_index=1, threshold=3.3499999999999996, categories=None, is_continuous=True),
                           Split(feature_index=1, threshold=3.45, categories=None, is_continuous=True),
                           Split(feature_index=1, threshold=3.6500000000000004, categories=None, is_continuous=True)],
                          [Split(feature_index=2, threshold=1.35, categories=None, is_continuous=True),
                           Split(feature_index=2, threshold=1.45, categories=None, is_continuous=True),
                           Split(feature_index=2, threshold=1.65, categories=None, is_continuous=True),
                           Split(feature_index=2, threshold=3.55, categories=None, is_continuous=True),
                           Split(feature_index=2, threshold=4.15, categories=None, is_continuous=True),
                           Split(feature_index=2, threshold=4.45, categories=None, is_continuous=True),
                           Split(feature_index=2, threshold=4.75, categories=None, is_continuous=True),
                           Split(feature_index=2, threshold=5.05, categories=None, is_continuous=True),
                           Split(feature_index=2, threshold=5.45, categories=None, is_continuous=True),
                           Split(feature_index=2, threshold=5.85, categories=None, is_continuous=True)],
                          [Split(feature_index=3, threshold=0.15000000000000002, categories=None, is_continuous=True),
                           Split(feature_index=3, threshold=0.25, categories=None, is_continuous=True),
                           Split(feature_index=3, threshold=0.35, categories=None, is_continuous=True),
                           Split(feature_index=3, threshold=1.05, categories=None, is_continuous=True),
                           Split(feature_index=3, threshold=1.25, categories=None, is_continuous=True),
                           Split(feature_index=3, threshold=1.35, categories=None, is_continuous=True),
                           Split(feature_index=3, threshold=1.55, categories=None, is_continuous=True),
                           Split(feature_index=3, threshold=1.75, categories=None, is_continuous=True),
                           Split(feature_index=3, threshold=1.95, categories=None, is_continuous=True),
                           Split(feature_index=3, threshold=2.25, categories=None, is_continuous=True)]]
